==> apache-cassandra-analytics-0.1.0-src.tar.gz: apache-cassandra-analytics-0.1.0-src/cassandra-analytics-common/src/test/java/org/apache/cassandra/spark/utils/LoggerHelperTests.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.cassandra.spark.utils;

import org.junit.jupiter.api.Test;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import static org.junit.jupiter.api.Assertions.assertArrayEquals;
import static org.junit.jupiter.api.Assertions.assertEquals;

public class LoggerHelperTests
{
    private static final Logger LOGGER = LoggerFactory.getLogger(LoggerHelperTests.class);

    @Test
    public void testBuildArgs()
    {
        LoggerHelper loggerHelper = new LoggerHelper(LOGGER, "a", "1", "b", "2", "c", "3");
        Object[] additionalArgs = new Object[]{"d", "4", "e", "5", "f", "6"};
        assertEquals("hello this is the log message a={} b={} c={} d={} e={} f={}", loggerHelper.logMsg("hello this is the log message", additionalArgs));
        assertArrayEquals(new Object[]{"1", "2", "3", "4", "5", "6"}, loggerHelper.buildArguments(null, additionalArgs));
        Throwable throwable = new RuntimeException("Error");
        assertArrayEquals(new Object[]{"1", "2", "3", "4", "5", "6", throwable}, loggerHelper.buildArguments(throwable, additionalArgs));
    }
}

==> apache-cassandra-analytics-0.2.0-src.tar.gz: apache-cassandra-analytics-0.2.0-src/cassandra-analytics-common/src/test/java/org/apache/cassandra/spark/utils/LoggerHelperTests.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.cassandra.spark.utils;

import org.junit.jupiter.api.Test;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import static org.assertj.core.api.Assertions.assertThat;

public class LoggerHelperTests
{
    private static final Logger LOGGER = LoggerFactory.getLogger(LoggerHelperTests.class);

    @Test
    public void testBuildArgs()
    {
        LoggerHelper loggerHelper = new LoggerHelper(LOGGER, "a", "1", "b", "2", "c", "3");
        Object[] additionalArgs = new Object[]{"d", "4", "e", "5", "f", "6"};
        assertThat(loggerHelper.logMsg("hello this is the log message", additionalArgs))
        .isEqualTo("hello this is the log message a={} b={} c={} d={} e={} f={}");
        assertThat(loggerHelper.buildArguments(null, additionalArgs))
        .isEqualTo(new Object[]{"1", "2", "3", "4", "5", "6"});
        Throwable throwable = new RuntimeException("Error");
        assertThat(loggerHelper.buildArguments(throwable, additionalArgs))
        .isEqualTo(new Object[]{"1", "2", "3", "4", "5", "6", throwable});
    }
}
